@@ -102,15 +102,14 @@ Q = qarts;
 Q.INCLUDES            = { fullfile( arts_includes, 'general.arts' ), ...
                           fullfile( arts_includes, 'continua.arts' ) };
 Q.ATMOSPHERE_DIM      = 1;
-Q.USE_RAW_ATMOSPHERE  = false;
 Q.STOKES_DIM          = 1;
 Q.J_DO                = true;
+Q.CLOUDBOX_DO         = false;
 
 
 %- Radiative transfer
 %
 Q.Y_UNIT              = 'RJBT'; 
-Q.WSMS_BEFORE_RTE     = { 'atm_checkedCalc' };
 Q.YCALC_WSMS          = { 'yCalc' };
 %
 Q.PPATH_LMAX          = 250;
@@ -129,7 +128,7 @@ Q.Z_SURFACE          = 5e3;          % Just a dummy value. A 10 km
 Q.ABS_LINES           = fullfile( atmlab_example_data, 'o3line111ghz' );
 Q.ABS_LINES_FORMAT    = 'Arts';
 %
-Q.ABSORPTION          = 'CalcTable';
+Q.ABSORPTION          = 'OnTheFly';
 Q.ABS_NLS             = [];
 
 %- Pressure grid
@@ -151,6 +150,7 @@ H                     = qartsSensor;
 %
 H.SENSOR_NORM         = true;
 %
+H.BACKEND_DO          = true;
 df                    = 0.5e6;
 H.F_BACKEND           = [ min(Q.F_GRID)+df : df : max(Q.F_GRID)-df ]';
 %
@@ -185,15 +185,22 @@ clear H f
 
 %- Define L2 structure (beside retrieval quantities below)
 %
-Q.L2_EXTRA = { 'cost', 'dx', 'xa', 'y', 'yf', 'bl', 'ptz', 'mresp', ...
+Q.L2_EXTRA = { 'cost', 'dx', 'xa', 'y', 'yf', 'bl', 'ptz', 'mresp', 'A', ...
                'e', 'eo', 'es', 'date' };
 
 
 %- Temperature
 %
-Q.T_ATMDATA = gf_artsxml( fullfile( arts_xmldata_path, 'climatology', ...
+Q.T.RETRIEVE = false;
+Q.T.ATMDATA  = gf_artsxml( fullfile( arts_xmldata_path, 'climatology', ...
                         'msis90', 'msis90.t.xml' ), 'Temperature', 't_field' );
 
+%- Determine altitudes through HSE
+%
+Q.HSE.ON       = true;
+Q.HSE.P        = 1013;
+Q.HSE.ACCURACY = 0.1;
+
 
 %- Species
 
@@ -202,22 +209,57 @@ Q.ABS_SPECIES(1).TAG      = { 'O3' };
 Q.ABS_SPECIES(1).RETRIEVE = true;
 Q.ABS_SPECIES(1).L2       = true;
 Q.ABS_SPECIES(1).GRIDS    = { z2p_simple(Q.Z_SURFACE+1e3:2e3:z_toa)', [], [] };
-Q.ABS_SPECIES(1).UNIT     = 'vmr';
-Q.ABS_SPECIES(1).SX       = ...
+Q.ABS_SPECIES(1).ATMDATA  = gf_artsxml( fullfile( fascod, ...
+                            'midlatitude-winter.O3.xml' ), 'O3', 'vmr_field' );
+switch 1
+ case 1  % Constant VMR
+  Q.ABS_SPECIES(1).UNIT     = 'vmr';
+  Q.ABS_SPECIES(1).SX       = ...
                      covmat1d_from_cfun( Q.ABS_SPECIES(1).GRIDS{1}, 1.5e-6, ...
                                                'lin', 0.2, 0.00, @log10 ) + ...
                      covmat1d_from_cfun( Q.ABS_SPECIES(1).GRIDS{1}, 0.3e-6, ...
                                                'lin', 0.5, 0.00, @log10 );
-Q.ABS_SPECIES(1).ATMDATA  = gf_artsxml( fullfile( fascod, ...
-                            'midlatitude-winter.O3.xml' ), 'O3', 'vmr_field' );
+ case 2 % Constant rel
+  Q.ABS_SPECIES(1).UNIT     = 'rel';
+  Q.ABS_SPECIES(1).SX       = ...
+                     covmat1d_from_cfun( Q.ABS_SPECIES(1).GRIDS{1}, 0.5, ...
+                                               'lin', 0.2, 0.00, @log10 ) + ...
+                     covmat1d_from_cfun( Q.ABS_SPECIES(1).GRIDS{1}, 0.1, ...
+                                               'lin', 0.5, 0.00, @log10 );
+ case 3 % Mimic case 2 in vmr
+  Q.ABS_SPECIES(1).UNIT     = 'vmr';
+  Q.ABS_SPECIES(1).SX       = ...
+                     covmat1d_from_cfun( Q.ABS_SPECIES(1).GRIDS{1}, ...
+                                       [ Q.ABS_SPECIES(1).ATMDATA.GRID1,...
+                                   0.5 * Q.ABS_SPECIES(1).ATMDATA.DATA ],...
+                                               'lin', 0.2, 0.00, @log10 ) + ...
+                     covmat1d_from_cfun( Q.ABS_SPECIES(1).GRIDS{1}, ...
+                                       [ Q.ABS_SPECIES(1).ATMDATA.GRID1, ...
+                                   0.1 * Q.ABS_SPECIES(1).ATMDATA.DATA ],...
+                                               'lin', 0.5, 0.00, @log10 );
 
+ case 4 % Constant logrel
+  Q.ABS_SPECIES(1).UNIT     = 'logrel';
+  Q.ABS_SPECIES(1).SX       = ...
+                     covmat1d_from_cfun( Q.ABS_SPECIES(1).GRIDS{1}, 0.5, ...
+                                               'lin', 0.2, 0.00, @log10 ) + ...
+                     covmat1d_from_cfun( Q.ABS_SPECIES(1).GRIDS{1}, 0.1, ...
+                                               'lin', 0.5, 0.00, @log10 );
+end  
+  
+  
+  
 %- Water 
 %
-Q.ABS_SPECIES(2).TAG      = { 'H2O-PWR98' };
+% This generates no absorption, as linefile has no H2O lines
+%
+Q.ABS_SPECIES(2).TAG      = { 'H2O' };
 Q.ABS_SPECIES(2).RETRIEVE = false;
 Q.ABS_SPECIES(2).ATMDATA  = gf_artsxml( fullfile( fascod, ...
                           'midlatitude-winter.H2O.xml' ), 'H2O', 'vmr_field' );
 
+% O2 and N2 not active, to make example somewhat faster
+if 0
 %- Oxygen
 %
 Q.ABS_SPECIES(3).TAG      = { 'O2-PWR93' };
@@ -231,6 +273,7 @@ Q.ABS_SPECIES(4).TAG      = { 'N2-SelfContStandardType' };
 Q.ABS_SPECIES(4).RETRIEVE = false;
 Q.ABS_SPECIES(4).ATMDATA  = gf_artsxml( fullfile( fascod, ...
                             'midlatitude-winter.N2.xml' ), 'N2', 'vmr_field' );
+end
 
 
 
@@ -311,6 +354,8 @@ Y.F = Q.SENSOR_RESPONSE.F_BACKEND;
 % Thermal noise standard deviation
 %
 Y.TNOISE = 0.05;
+% To test varying noise
+%Y.TNOISE = linspace( 0.03, 0.07, length(Y.F) )';
 
 % Simulate a measurement
 %
@@ -333,7 +378,7 @@ Y = qpack2( Q, oem, Y );            % Dummy oem structure OK here
 % The correlation specified in Q is included
 %
 for i = 1 : length(Y)
-  Y(i).Y = Y(i).Y + Y(i).TNOISE * make_noise(1,Q.TNOISE_C);
+  Y(i).Y = Y(i).Y + Y(i).TNOISE .* make_noise(1,Q.TNOISE_C);
 end
 
 % Add a constant "baseline shift" for measurement 2
