@@ -10,30 +10,43 @@
 %    lat = loadncvar( 'mydata.nc', 'lat');
 %    grid = loadncvar( 'mydata.nc', { 'lat', 'lon' } );
 %    
+%    Note: If you wish to load the whole netcdf file into a structure use
+%          struct = loadncfile (filename), instead.
 %
-% FORMAT   ret = loadncvar( filename, varname )
+% FORMAT   [ret, attr] = loadncvar( filename, varname )
 %        
 % OUT   ret        Loaded variable.
+% OUT   attr       Global attributes.
 % IN    filename   Name of NetCDF file.
 %       varname    Name of variable.
 
 % 2010-02-02   Created by Oliver Lemke.
+% 2010-10-11   Modified by Gerrit Holl.
+% 2010-11-22   Modified by Salomon Eliasson.
+% 2012-01-30   Modified by Gerrit Holl.
 
-
-function ret = loadncvar( filename, varname )
+function [ret, attr] = loadncvar( filename, varname )
   
 ncid = netcdf.open (filename, 'NOWRITE');
 
+if (nargout>1)
+  attr = getncattributes (ncid);
+else
+  attr = [];
+end
+
 if ischar(varname)
-    varid = netcdf.inqVarId (ncid, varname);
-    ret = netcdf.getVar (ncid, varid);
+    varid = netcdf.inqVarID (ncid, varname);
+    ret = nc_read_varid(ncid, varid);
 elseif iscell(varname)
-    for v = varname
-        varid = netcdf.inqVarId (ncid, char(v));
-        ret.(genvarname(char(v))) = netcdf.getVar (ncid, varid);
+    for v = varname(:).'
+        varid = netcdf.inqVarID (ncid, v{1});
+        ret.(genvarname(v{1})) = nc_read_varid(ncid, varid);
     end
 else
     error 'varname must be either of type char or cell';
 end
 
-netcdf.close (ncid);
\ No newline at end of file
+netcdf.close (ncid);
+
+end
